@@ -80,6 +80,9 @@ void MainWindow::on_pbEdit_clicked()
 {
         Dialog *w;
         w = new Dialog(0);
+
+        //settingsdlg *w;
+        //w = new settingsdlg(0);
         w->exec();
         SetupThisUi();
         delete w;
@@ -92,7 +95,6 @@ void MainWindow::SetupThisUi()
     QSettings *oSettings;
     oSettings = new QSettings("janbergmann", "simplenotewidget");
     QColor cldefault = oSettings->value("bgcolor", QColor(255,255,0)).value<QColor>();
-    QColor cllabelcolor = oSettings->value("lblcolor", QColor(0,0,0)).value<QColor>();
     QColor cltextedit = oSettings->value("txtcolor", QColor(0,0,0)).value<QColor>();
     int bgcoloralpha = oSettings->value("bgcoloralpha", int(180)).toInt();
     cldefault.setAlpha(bgcoloralpha);
@@ -147,12 +149,20 @@ void MainWindow::SetupThisUi()
     ui->teMain->setWordWrapMode(QTextOption::WrapAtWordBoundaryOrAnywhere);
     ui->teMain->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     ui->teMain->setReadOnly(true);
-    ui->teMain->setStyleSheet( "background-color: rgba( 255, 255, 0, 0% );" );
+
+
+    QVariant vRed (cltextedit.red());
+    QVariant vGreen (cltextedit.green());
+    QVariant vBlue (cltextedit.blue());
+
+    ui->teMain->setStyleSheet( "background-color: rgba( " + vRed.toString() + ", " + vGreen.toString() +  ", " + vBlue.toString() + ", 0% );" );
+    ui->teMain->setPalette(QPalette(cltextedit,cldefault,cldefault,cltextedit,cltextedit,cltextedit,cldefault,cldefault,cldefault));
+    //ui->teMain->repaint();
 
 
 
     ui->lblDate->setLayoutDirection(Qt::RightToLeft);
-    ui->lblDate->setPalette(QPalette(cllabelcolor,cllabelcolor,cllabelcolor,cllabelcolor,cllabelcolor,cllabelcolor,cldefault,cldefault,cldefault));
+    ui->lblDate->setPalette(QPalette(cltextedit,cltextedit,cltextedit,cltextedit,cltextedit,cltextedit,cldefault,cldefault,cldefault));
     ui->lblDate->setFont(QFont(fontFamilyName,10,10));
 
 
@@ -165,8 +175,8 @@ void MainWindow::SetupThisUi()
 
 #ifdef Q_WS_HILDON
        this->setProperty("FingerScrollable", true);
-       this->setFocusPolicy(Qt::StrongFocus);
        ui->teMain->setFocusPolicy(Qt::StrongFocus);
+       this->setFocusPolicy(Qt::StrongFocus);
        ui->teMain->setProperty("FingerScrollable", true);
 #endif
 
